@@ -7,7 +7,7 @@ use utf8;
 
 BEGIN {
 	$MooseX::DeclareX::AUTHORITY = 'cpan:TOBYINK';
-	$MooseX::DeclareX::VERSION   = '0.005';
+	$MooseX::DeclareX::VERSION   = '0.006';
 }
 
 use constant DEFAULT_KEYWORDS => [qw(class role exception)];
@@ -23,10 +23,14 @@ sub import
 	my ($class, %args) = @_;
 	my $caller = caller(0);
 
-	if (my $types = delete $args{types})
+	# Simplified interface for a couple of standard plugins
+	foreach my $awesome (qw/ types imports /)
 	{
-		$args{plugins} ||= DEFAULT_PLUGINS;
-		push @{ $args{plugins} }, types => $types;
+		if (my $ness = delete $args{$awesome})
+		{
+			$args{plugins} ||= DEFAULT_PLUGINS;
+			push @{ $args{plugins} }, $awesome, $ness;
+		}
 	}
 
 	$_->setup_for($caller, %args, provided_by => $class) for __PACKAGE__->_keywords(\%args);
@@ -90,25 +94,25 @@ MooseX::DeclareX - more sugar for MooseX::Declare
   use 5.010;
   use MooseX::DeclareX
     keywords => [qw(class exception)],
-    plugins  => [qw(guard build preprocess)],
-    ;
+    plugins  => [qw(guard build preprocess std_constants)],
+    types    => [ -Moose ];
   
   class Banana;
   
   exception BananaError
   {
     has origin => (
-      is       => 'rw',
-      isa      => 'Monkey',
-      required => 1,
+      is       => read_write,
+      isa      => Object,
+      required => true,
     );
   }
   
   class Monkey
   {
     has name => (
-      is       => 'rw',
-      isa      => 'Str',
+      is       => read_write,
+      isa      => Str,
     );
     
     build name {
@@ -117,8 +121,8 @@ MooseX::DeclareX - more sugar for MooseX::Declare
     }  
     
     has bananas => (
-      is       => 'rw',
-      isa      => 'ArrayRef[Banana]',
+      is       => read_write,
+      isa      => ArrayRef[ Object ],
       traits   => ['Array'],
       handles  => {
         give_banana  => 'push',
@@ -200,14 +204,14 @@ That is, it creates a class which is a subclass of L<Throwable::Error>.
 This is some sugar for creating builder methods. The following two examples
 are roughly equivalent:
 
-	build fullname {
-		join q( ), $self->firstname, $self->surname;
-	}
+  build fullname {
+    join q( ), $self->firstname, $self->surname;
+  }
 
-	sub _build_fullname {
-		my $self = shift;
-		join q( ), $self->firstname, $self->surname;
-	}
+  sub _build_fullname {
+    my $self = shift;
+    join q( ), $self->firstname, $self->surname;
+  }
 
 However, C<build> also performs a little housekeeping for you. If an attribute
 does not exist with the same name as the builder, it will create one for you
@@ -220,23 +224,23 @@ attribute already exists but does not have a builder set, then it will set it.
 Simplifies a common usage pattern for C<around>. A guard protects a method,
 preventing it from being called unless a condition evaluates to true.
 
-	class Doorway
-	{
-		method enter ($person)
-		{
-			...
-		}
-	}
-	
-	class Doorway::Protected
-	{
-		has password => (is => 'ro', isa => 'Str');
-		
-		guard enter ($person)
-		{
-			$person->knows( $self->password )
-		}
-	}
+  class Doorway
+  {
+    method enter ($person)
+    {
+      ...
+    }
+  }
+  
+  class Doorway::Protected
+  {
+    has password => (is => 'ro', isa => 'Str');
+    
+    guard enter ($person)
+    {
+      $person->knows( $self->password )
+    }
+  }
 
 =item C<preprocess>
 
@@ -244,19 +248,19 @@ Another simplification for a common usage pattern for C<around>. Acts much
 like C<before>, but B<can> modify the parameters seen by the base method.
 In fact, it must return the processed parameters as a list.
 
-	class Speaker
-	{
-		method speak (@words) {
-			say for @words;
-		}
-	}
-	
-	class Speaker::Loud
-	{
-		preprocess speak {
-			return map { uc($_) } @_
-		}
-	}
+  class Speaker
+  {
+    method speak (@words) {
+      say for @words;
+    }
+  }
+  
+  class Speaker::Loud
+  {
+    preprocess speak {
+      return map { uc($_) } @_
+    }
+  }
 
 =item C<postprocess>
 
@@ -273,9 +277,9 @@ std_constants plugin.
 
 You should indicate which features you are using:
 
-	use MooseX::DeclareX
-		keywords => [qw(class role exception)],
-		plugins  => [qw(guard build)];
+  use MooseX::DeclareX
+    keywords => [qw(class role exception)],
+    plugins  => [qw(guard build)];
 
 What is the distinction between keywords and plugins? Keywords are the words
 that declare class-like things. Plugins are the other bits, and only work
@@ -288,11 +292,11 @@ too.
 
 If you don't specify a list of keywords, then the default list is:
 
-	[qw(class role exception)]
+  [qw(class role exception)]
 
 If you don't specify a list of plugins, then the default list is:
 
-	[qw(build guard std_constants)]
+  [qw(build guard std_constants)]
 
 That is, there are certain pieces of functionality which are not available
 by default - they need to be loaded explicitly! 
@@ -308,13 +312,30 @@ easily:
     types    => [
       -Moose,                 # use MooseX::Types::Moose -all
       -URI => [qw(FileUri)],  # use MooseX::Types::URI qw(FileUri)
-		'Foo::Types',           # use Foo::Types -all
+      'Foo::Types',           # use Foo::Types -all
     ];
 
 As per the example, any module which does not include an arrayref of import
 parameters, gets "-all". A leading hyphen is interpreted as an abbreviation
 for "MooseX::Types::".
 
+=head2 Additional Import Syntactic Sugar
+
+You can specify a list of additional modules that will always be imported
+"inside" your class/role definitions.
+
+  use MooseX::DeclareX
+    keywords => [qw(class role exception)],
+    plugins  => [qw(build guard std_constants)],
+    imports  => [
+      'MooseX::ClassAttribute',
+      'Path::Class'      => [qw( file dir )],
+      'Perl6::Junction'  => [qw( any all none )],
+      'List::Util'       => [qw( first reduce )],
+    ];
+
+In fact, this is just a minor generalisation of the MooseX::Types feature.
+
 =head1 BUGS
 
 Please report any bugs to
